
#include "interrupt.h"
#include "stm32f4xx_tim.h"

extern xQueueHandle xQueueCAN2,xQueueCAN1;



/**
  * @brief  Configures the NVIC.
  * @param  None
  * @retval None
  */
void InterruptCAN_Init(void)
{
  NVIC_InitTypeDef NVIC_InitStructure;

  NVIC_InitStructure.NVIC_IRQChannel = CAN2_RX0_IRQn;

  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority =configLIBRARY_MAX_SYSCALL_INTERRUPT_PRIORITY+1;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;

  NVIC_Init(&NVIC_InitStructure);

  NVIC_InitStructure.NVIC_IRQChannel = CAN1_RX1_IRQn;

  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority =configLIBRARY_MAX_SYSCALL_INTERRUPT_PRIORITY+1;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;

  NVIC_Init(&NVIC_InitStructure);
}
/**
  * @brief  The ISR that will give the semaphore to unblock the vTask_SendRequest Task
  * @param  None
  * @retval None
  */
void CAN2_RX0_IRQHandler(void)
{
  CanRxMsg RxMessage;
  portBASE_TYPE xHigherPriorityTaskWoken;

  RxMessage.StdId = 0x00;
  RxMessage.ExtId = 0x00;
  RxMessage.IDE = 0;
  RxMessage.DLC = 0;
  RxMessage.FMI = 0;
  RxMessage.Data[0] = 0x00;
  RxMessage.Data[1] = 0x00;

  xHigherPriorityTaskWoken = pdFALSE;

  CAN_Receive(CAN2, CAN_FIFO0, &RxMessage);

  xQueueSendToFrontFromISR( xQueueCAN2, &RxMessage, &xHigherPriorityTaskWoken );

  if( xHigherPriorityTaskWoken )
  	{
	  portYIELD();
  	}

}




/**
  * @brief  This function handles CAN1 RX1 request.
  * @param  None
  * @retval None
  */
void CAN1_RX1_IRQHandler(void)
{
  CanRxMsg RxMessage;
  portBASE_TYPE xHigherPriorityTaskWoken;

  RxMessage.StdId = 0x00;
  RxMessage.ExtId = 0x00;
  RxMessage.IDE = 0;
  RxMessage.DLC = 0;
  RxMessage.FMI = 0;
  RxMessage.Data[0] = 0x00;
  RxMessage.Data[1] = 0x00;

  CAN_Receive(CAN1, CAN_FIFO1, &RxMessage);



  if( xHigherPriorityTaskWoken )
  	{
	  portYIELD();
  	}



}

